@@ -1,3 +1,5 @@
+// SPDX-License-Identifier: Apache-2.0
+// 
 // Copyright 2008-2016 Conrad Sanderson (http://conradsanderson.id.au)
 // Copyright 2008-2016 National ICT Australia (NICTA)
 // 
@@ -69,12 +71,11 @@ SpBase<elem_type,derived>::st() const
 
 
 template<typename elem_type, typename derived>
-arma_cold
 inline
 void
 SpBase<elem_type,derived>::print(const std::string extra_text) const
   {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
   
   const unwrap_spmat<derived> tmp( (*this).get_ref() );
   
@@ -93,12 +94,11 @@ SpBase<elem_type,derived>::print(const std::string extra_text) const
 
 
 template<typename elem_type, typename derived>
-arma_cold
 inline
 void
 SpBase<elem_type,derived>::print(std::ostream& user_stream, const std::string extra_text) const
   {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
   
   const unwrap_spmat<derived> tmp( (*this).get_ref() );
   
@@ -117,12 +117,11 @@ SpBase<elem_type,derived>::print(std::ostream& user_stream, const std::string ex
 
 
 template<typename elem_type, typename derived>
-arma_cold
 inline
 void
 SpBase<elem_type,derived>::raw_print(const std::string extra_text) const
   {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
   
   const unwrap_spmat<derived> tmp( (*this).get_ref() );
   
@@ -141,12 +140,11 @@ SpBase<elem_type,derived>::raw_print(const std::string extra_text) const
 
 
 template<typename elem_type, typename derived>
-arma_cold
 inline
 void
 SpBase<elem_type,derived>::raw_print(std::ostream& user_stream, const std::string extra_text) const
   {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
   
   const unwrap_spmat<derived> tmp( (*this).get_ref() );
   
@@ -165,12 +163,11 @@ SpBase<elem_type,derived>::raw_print(std::ostream& user_stream, const std::strin
 
 
 template<typename elem_type, typename derived>
-arma_cold
 inline
 void
 SpBase<elem_type, derived>::print_dense(const std::string extra_text) const
   {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
   
   const unwrap_spmat<derived> tmp( (*this).get_ref() );
 
@@ -189,12 +186,11 @@ SpBase<elem_type, derived>::print_dense(const std::string extra_text) const
 
 
 template<typename elem_type, typename derived>
-arma_cold
 inline
 void
 SpBase<elem_type, derived>::print_dense(std::ostream& user_stream, const std::string extra_text) const
   {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
   
   const unwrap_spmat<derived> tmp( (*this).get_ref() );
 
@@ -213,12 +209,11 @@ SpBase<elem_type, derived>::print_dense(std::ostream& user_stream, const std::st
 
 
 template<typename elem_type, typename derived>
-arma_cold
 inline
 void
 SpBase<elem_type, derived>::raw_print_dense(const std::string extra_text) const
   {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
   
   const unwrap_spmat<derived> tmp( (*this).get_ref() );
 
@@ -237,12 +232,11 @@ SpBase<elem_type, derived>::raw_print_dense(const std::string extra_text) const
 
 
 template<typename elem_type, typename derived>
-arma_cold
 inline
 void
 SpBase<elem_type, derived>::raw_print_dense(std::ostream& user_stream, const std::string extra_text) const
   {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
   
   const unwrap_spmat<derived> tmp( (*this).get_ref() );
 
@@ -261,12 +255,11 @@ SpBase<elem_type, derived>::raw_print_dense(std::ostream& user_stream, const std
 
 
 template<typename elem_type, typename derived>
-arma_cold
 inline
 void
 SpBase<elem_type,derived>::brief_print(const std::string extra_text) const
   {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
   
   const unwrap_spmat<derived> tmp( (*this).get_ref() );
   
@@ -285,12 +278,11 @@ SpBase<elem_type,derived>::brief_print(const std::string extra_text) const
 
 
 template<typename elem_type, typename derived>
-arma_cold
 inline
 void
 SpBase<elem_type,derived>::brief_print(std::ostream& user_stream, const std::string extra_text) const
   {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
   
   const unwrap_spmat<derived> tmp( (*this).get_ref() );
   
@@ -316,7 +308,7 @@ inline
 const derived&
 SpBase_eval_SpMat<elem_type, derived>::eval() const
   {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
   
   return static_cast<const derived&>(*this);
   }
@@ -331,7 +323,7 @@ inline
 SpMat<elem_type>
 SpBase_eval_expr<elem_type, derived>::eval() const
   {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
   
   return SpMat<elem_type>( static_cast<const derived&>(*this) );
   }
@@ -340,22 +332,20 @@ SpBase_eval_expr<elem_type, derived>::eval() const
 
 template<typename elem_type, typename derived>
 inline
-arma_warn_unused
 elem_type
 SpBase<elem_type, derived>::min() const
   {
-  return spop_min::min( (*this).get_ref() );
+  return op_sp_min::min( (*this).get_ref() );
   }
 
 
 
 template<typename elem_type, typename derived>
 inline
-arma_warn_unused
 elem_type
 SpBase<elem_type, derived>::max() const
   {
-  return spop_max::max( (*this).get_ref() );
+  return op_sp_max::max( (*this).get_ref() );
   }
 
 
@@ -367,7 +357,7 @@ SpBase<elem_type, derived>::min(uword& index_of_min_val) const
   {
   const SpProxy<derived> P( (*this).get_ref() );
   
-  return spop_min::min_with_index(P, index_of_min_val);
+  return op_sp_min::min_with_index(P, index_of_min_val);
   }
 
 
@@ -379,7 +369,7 @@ SpBase<elem_type, derived>::max(uword& index_of_max_val) const
   {
   const SpProxy<derived> P( (*this).get_ref() );
   
-  return spop_max::max_with_index(P, index_of_max_val);
+  return op_sp_max::max_with_index(P, index_of_max_val);
   }
 
 
@@ -393,7 +383,7 @@ SpBase<elem_type, derived>::min(uword& row_of_min_val, uword& col_of_min_val) co
   
   uword index = 0;
   
-  const elem_type val = spop_min::min_with_index(P, index);
+  const elem_type val = op_sp_min::min_with_index(P, index);
   
   const uword local_n_rows = P.get_n_rows();
   
@@ -414,7 +404,7 @@ SpBase<elem_type, derived>::max(uword& row_of_max_val, uword& col_of_max_val) co
   
   uword index = 0;
   
-  const elem_type val = spop_max::max_with_index(P, index);
+  const elem_type val = op_sp_max::max_with_index(P, index);
   
   const uword local_n_rows = P.get_n_rows();
   
@@ -428,7 +418,6 @@ SpBase<elem_type, derived>::max(uword& row_of_max_val, uword& col_of_max_val) co
 
 template<typename elem_type, typename derived>
 inline
-arma_warn_unused
 uword
 SpBase<elem_type,derived>::index_min() const
   {
@@ -438,11 +427,11 @@ SpBase<elem_type,derived>::index_min() const
   
   if(P.get_n_elem() == 0)
     {
-    arma_debug_check(true, "index_min(): object has no elements");
+    arma_conform_check(true, "index_min(): object has no elements");
     }
   else
     {
-    spop_min::min_with_index(P, index);
+    op_sp_min::min_with_index(P, index);
     }
   
   return index;
@@ -452,7 +441,6 @@ SpBase<elem_type,derived>::index_min() const
 
 template<typename elem_type, typename derived>
 inline
-arma_warn_unused
 uword
 SpBase<elem_type,derived>::index_max() const
   {
@@ -462,11 +450,11 @@ SpBase<elem_type,derived>::index_max() const
   
   if(P.get_n_elem() == 0)
     {
-    arma_debug_check(true, "index_max(): object has no elements");
+    arma_conform_check(true, "index_max(): object has no elements");
     }
   else
     {
-    spop_max::max_with_index(P, index);
+    op_sp_max::max_with_index(P, index);
     }
   
   return index;
@@ -476,11 +464,10 @@ SpBase<elem_type,derived>::index_max() const
 
 template<typename elem_type, typename derived>
 inline
-arma_warn_unused
 bool
 SpBase<elem_type,derived>::is_symmetric() const
   {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
   
   const unwrap_spmat<derived> tmp( (*this).get_ref() );
   
@@ -491,11 +478,10 @@ SpBase<elem_type,derived>::is_symmetric() const
 
 template<typename elem_type, typename derived>
 inline
-arma_warn_unused
 bool
 SpBase<elem_type,derived>::is_symmetric(const typename get_pod_type<elem_type>::result tol) const
   {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
   
   const unwrap_spmat<derived> tmp( (*this).get_ref() );
   
@@ -506,11 +492,10 @@ SpBase<elem_type,derived>::is_symmetric(const typename get_pod_type<elem_type>::
 
 template<typename elem_type, typename derived>
 inline
-arma_warn_unused
 bool
 SpBase<elem_type,derived>::is_hermitian() const
   {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
   
   const unwrap_spmat<derived> tmp( (*this).get_ref() );
   
@@ -521,11 +506,10 @@ SpBase<elem_type,derived>::is_hermitian() const
 
 template<typename elem_type, typename derived>
 inline
-arma_warn_unused
 bool
 SpBase<elem_type,derived>::is_hermitian(const typename get_pod_type<elem_type>::result tol) const
   {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
   
   const unwrap_spmat<derived> tmp( (*this).get_ref() );
   
@@ -536,15 +520,14 @@ SpBase<elem_type,derived>::is_hermitian(const typename get_pod_type<elem_type>::
 
 template<typename elem_type, typename derived>
 inline
-arma_warn_unused
 bool
 SpBase<elem_type,derived>::is_zero(const typename get_pod_type<elem_type>::result tol) const
   {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
   
   typedef typename get_pod_type<elem_type>::result T;
   
-  arma_debug_check( (tol < T(0)), "is_zero(): parameter 'tol' must be >= 0" );
+  arma_conform_check( (tol < T(0)), "is_zero(): parameter 'tol' must be >= 0" );
   
   const SpProxy<derived> P( (*this).get_ref() );
   
@@ -594,11 +577,10 @@ SpBase<elem_type,derived>::is_zero(const typename get_pod_type<elem_type>::resul
 
 template<typename elem_type, typename derived>
 inline
-arma_warn_unused
 bool
 SpBase<elem_type,derived>::is_trimatu() const
   {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
   
   const SpProxy<derived> P( (*this).get_ref() );
   
@@ -620,11 +602,10 @@ SpBase<elem_type,derived>::is_trimatu() const
 
 template<typename elem_type, typename derived>
 inline
-arma_warn_unused
 bool
 SpBase<elem_type,derived>::is_trimatl() const
   {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
   
   const SpProxy<derived> P( (*this).get_ref() );
   
@@ -646,11 +627,10 @@ SpBase<elem_type,derived>::is_trimatl() const
 
 template<typename elem_type, typename derived>
 inline
-arma_warn_unused
 bool
 SpBase<elem_type,derived>::is_diagmat() const
   {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
   
   const SpProxy<derived> P( (*this).get_ref() );
   
@@ -670,11 +650,10 @@ SpBase<elem_type,derived>::is_diagmat() const
 
 template<typename elem_type, typename derived>
 inline
-arma_warn_unused
 bool
 SpBase<elem_type,derived>::is_empty() const
   {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
   
   const SpProxy<derived> P( (*this).get_ref() );
   
@@ -685,11 +664,10 @@ SpBase<elem_type,derived>::is_empty() const
 
 template<typename elem_type, typename derived>
 inline
-arma_warn_unused
 bool
 SpBase<elem_type,derived>::is_square() const
   {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
   
   const SpProxy<derived> P( (*this).get_ref() );
   
@@ -700,11 +678,10 @@ SpBase<elem_type,derived>::is_square() const
 
 template<typename elem_type, typename derived>
 inline
-arma_warn_unused
 bool
 SpBase<elem_type,derived>::is_vec() const
   {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
   
   if( (SpProxy<derived>::is_row) || (SpProxy<derived>::is_col) || (SpProxy<derived>::is_xvec) )  { return true; }
   
@@ -717,11 +694,10 @@ SpBase<elem_type,derived>::is_vec() const
 
 template<typename elem_type, typename derived>
 inline
-arma_warn_unused
 bool
 SpBase<elem_type,derived>::is_colvec() const
   {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
   
   if(SpProxy<derived>::is_col)  { return true; }
   
@@ -734,11 +710,10 @@ SpBase<elem_type,derived>::is_colvec() const
 
 template<typename elem_type, typename derived>
 inline
-arma_warn_unused
 bool
 SpBase<elem_type,derived>::is_rowvec() const
   {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
   
   if(SpProxy<derived>::is_row)  { return true; }
   
@@ -751,22 +726,23 @@ SpBase<elem_type,derived>::is_rowvec() const
 
 template<typename elem_type, typename derived>
 inline
-arma_warn_unused
 bool
 SpBase<elem_type,derived>::is_finite() const
   {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
   
-  const SpProxy<derived> P( (*this).get_ref() );
+  if(arma_config::fast_math_warn)  { arma_warn(1, "is_finite(): detection of non-finite values is not reliable in fast math mode"); }
   
   if(is_SpMat<typename SpProxy<derived>::stored_type>::value)
     {
-    const unwrap_spmat<typename SpProxy<derived>::stored_type> U(P.Q);
+    const unwrap_spmat<derived> U( (*this).get_ref() );
     
-    return U.M.is_finite();
+    return U.M.internal_is_finite();
     }
   else
     {
+    const SpProxy<derived> P( (*this).get_ref() );
+    
     typename SpProxy<derived>::const_iterator_type it     = P.begin();
     typename SpProxy<derived>::const_iterator_type it_end = P.end();
     
@@ -784,22 +760,23 @@ SpBase<elem_type,derived>::is_finite() const
 
 template<typename elem_type, typename derived>
 inline
-arma_warn_unused
 bool
 SpBase<elem_type,derived>::has_inf() const
   {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
   
-  const SpProxy<derived> P( (*this).get_ref() );
+  if(arma_config::fast_math_warn)  { arma_warn(1, "has_inf(): detection of non-finite values is not reliable in fast math mode"); }
   
   if(is_SpMat<typename SpProxy<derived>::stored_type>::value)
     {
-    const unwrap_spmat<typename SpProxy<derived>::stored_type> U(P.Q);
+    const unwrap_spmat<derived> U( (*this).get_ref() );
     
-    return U.M.has_inf();
+    return U.M.internal_has_inf();
     }
   else
     {
+    const SpProxy<derived> P( (*this).get_ref() );
+    
     typename SpProxy<derived>::const_iterator_type it     = P.begin();
     typename SpProxy<derived>::const_iterator_type it_end = P.end();
     
@@ -817,22 +794,23 @@ SpBase<elem_type,derived>::has_inf() const
 
 template<typename elem_type, typename derived>
 inline
-arma_warn_unused
 bool
 SpBase<elem_type,derived>::has_nan() const
   {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
   
-  const SpProxy<derived> P( (*this).get_ref() );
+  if(arma_config::fast_math_warn)  { arma_warn(1, "has_nan(): detection of non-finite values is not reliable in fast math mode"); }
   
   if(is_SpMat<typename SpProxy<derived>::stored_type>::value)
     {
-    const unwrap_spmat<typename SpProxy<derived>::stored_type> U(P.Q);
+    const unwrap_spmat<derived> U( (*this).get_ref() );
     
-    return U.M.has_nan();
+    return U.M.internal_has_nan();
     }
   else
     {
+    const SpProxy<derived> P( (*this).get_ref() );
+    
     typename SpProxy<derived>::const_iterator_type it     = P.begin();
     typename SpProxy<derived>::const_iterator_type it_end = P.end();
     
@@ -850,7 +828,40 @@ SpBase<elem_type,derived>::has_nan() const
 
 template<typename elem_type, typename derived>
 inline
-arma_warn_unused
+bool
+SpBase<elem_type,derived>::has_nonfinite() const
+  {
+  arma_debug_sigprint();
+  
+  if(arma_config::fast_math_warn)  { arma_warn(1, "has_nonfinite(): detection of non-finite values is not reliable in fast math mode"); }
+  
+  if(is_SpMat<typename SpProxy<derived>::stored_type>::value)
+    {
+    const unwrap_spmat<derived> U( (*this).get_ref() );
+    
+    return U.M.internal_has_nonfinite();
+    }
+  else
+    {
+    const SpProxy<derived> P( (*this).get_ref() );
+    
+    typename SpProxy<derived>::const_iterator_type it     = P.begin();
+    typename SpProxy<derived>::const_iterator_type it_end = P.end();
+    
+    while(it != it_end)
+      {
+      if(arma_isfinite(*it) == false)  { return true; }
+      ++it;
+      }
+    }
+  
+  return false;
+  }
+
+
+
+template<typename elem_type, typename derived>
+inline
 const SpOp<derived,spop_vectorise_col>
 SpBase<elem_type, derived>::as_col() const
   {
@@ -861,7 +872,6 @@ SpBase<elem_type, derived>::as_col() const
 
 template<typename elem_type, typename derived>
 inline
-arma_warn_unused
 const SpOp<derived,spop_vectorise_row>
 SpBase<elem_type, derived>::as_row() const
   {
@@ -870,4 +880,14 @@ SpBase<elem_type, derived>::as_row() const
 
 
 
+template<typename elem_type, typename derived>
+inline
+const SpToDOp<derived,op_sp_as_dense>
+SpBase<elem_type, derived>::as_dense() const
+  {
+  return SpToDOp<derived,op_sp_as_dense>( (*this).get_ref() );
+  }
+
+
+
 //! @}
