@@ -30,16 +30,16 @@ eig_gen
   const char* option = "nobalance"
   )
   {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
   
   typedef typename T1::pod_type     T;
   typedef typename std::complex<T> eT;
   
   const char sig = (option != nullptr) ? option[0] : char(0);
   
-  arma_debug_check( ((sig != 'n') && (sig != 'b')), "eig_gen(): unknown option" );
+  arma_conform_check( ((sig != 'n') && (sig != 'b')), "eig_gen(): unknown option" );
   
-  if( auxlib::crippled_lapack(expr) && (sig == 'b') )  { arma_debug_warn_level(1,  "eig_gen(): 'balance' option ignored due to linking with crippled lapack"); }
+  if( auxlib::crippled_lapack(expr) && (sig == 'b') )  { arma_warn(1,  "eig_gen(): 'balance' option ignored due to linking with crippled lapack"); }
   
   Col<eT> eigvals;
   Mat<eT> eigvecs;
@@ -67,16 +67,16 @@ eig_gen
   const char* option = "nobalance"
   )
   {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
   
   typedef typename T1::pod_type     T;
   typedef typename std::complex<T> eT;
   
   const char sig = (option != nullptr) ? option[0] : char(0);
   
-  arma_debug_check( ((sig != 'n') && (sig != 'b')), "eig_gen(): unknown option" );
+  arma_conform_check( ((sig != 'n') && (sig != 'b')), "eig_gen(): unknown option" );
   
-  if( auxlib::crippled_lapack(expr) && (sig == 'b') )  { arma_debug_warn_level(1,  "eig_gen(): 'balance' option ignored due to linking with crippled lapack"); }
+  if( auxlib::crippled_lapack(expr) && (sig == 'b') )  { arma_warn(1,  "eig_gen(): 'balance' option ignored due to linking with crippled lapack"); }
   
   Mat<eT> eigvecs;
   
@@ -85,7 +85,7 @@ eig_gen
   if(status == false)
     {
     eigvals.soft_reset();
-    arma_debug_warn_level(3, "eig_gen(): decomposition failed");
+    arma_warn(3, "eig_gen(): decomposition failed");
     }
   
   return status;
@@ -104,15 +104,15 @@ eig_gen
   const char* option = "nobalance"
   )
   {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
   
-  arma_debug_check( (void_ptr(&eigvals) == void_ptr(&eigvecs)), "eig_gen(): parameter 'eigval' is an alias of parameter 'eigvec'" );
+  arma_conform_check( (void_ptr(&eigvals) == void_ptr(&eigvecs)), "eig_gen(): parameter 'eigval' is an alias of parameter 'eigvec'" );
   
   const char sig = (option != nullptr) ? option[0] : char(0);
   
-  arma_debug_check( ((sig != 'n') && (sig != 'b')), "eig_gen(): unknown option" );
+  arma_conform_check( ((sig != 'n') && (sig != 'b')), "eig_gen(): unknown option" );
   
-  if( auxlib::crippled_lapack(expr) && (sig == 'b') )  { arma_debug_warn_level(1,  "eig_gen(): 'balance' option ignored due to linking with crippled lapack"); }
+  if( auxlib::crippled_lapack(expr) && (sig == 'b') )  { arma_warn(1,  "eig_gen(): 'balance' option ignored due to linking with crippled lapack"); }
   
   const bool status = (sig == 'b') ? auxlib::eig_gen_balance(eigvals, eigvecs, true, expr.get_ref()) : auxlib::eig_gen(eigvals, eigvecs, true, expr.get_ref());
   
@@ -120,7 +120,7 @@ eig_gen
     {
     eigvals.soft_reset();
     eigvecs.soft_reset();
-    arma_debug_warn_level(3, "eig_gen(): decomposition failed");
+    arma_warn(3, "eig_gen(): decomposition failed");
     }
   
   return status;
@@ -140,17 +140,17 @@ eig_gen
   const char* option = "nobalance"
   )
   {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
   
-  arma_debug_check( (void_ptr(&eigvals)  == void_ptr(&leigvecs)), "eig_gen(): parameter 'eigval' is an alias of parameter 'leigvec'" );
-  arma_debug_check( (void_ptr(&eigvals)  == void_ptr(&reigvecs)), "eig_gen(): parameter 'eigval' is an alias of parameter 'reigvec'" );
-  arma_debug_check( (void_ptr(&leigvecs) == void_ptr(&reigvecs)), "eig_gen(): parameter 'leigvec' is an alias of parameter 'reigvec'" );
+  arma_conform_check( (void_ptr(&eigvals)  == void_ptr(&leigvecs)), "eig_gen(): parameter 'eigval' is an alias of parameter 'leigvec'" );
+  arma_conform_check( (void_ptr(&eigvals)  == void_ptr(&reigvecs)), "eig_gen(): parameter 'eigval' is an alias of parameter 'reigvec'" );
+  arma_conform_check( (void_ptr(&leigvecs) == void_ptr(&reigvecs)), "eig_gen(): parameter 'leigvec' is an alias of parameter 'reigvec'" );
   
   const char sig = (option != nullptr) ? option[0] : char(0);
   
-  arma_debug_check( ((sig != 'n') && (sig != 'b')), "eig_gen(): unknown option" );
+  arma_conform_check( ((sig != 'n') && (sig != 'b')), "eig_gen(): unknown option" );
   
-  if( auxlib::crippled_lapack(expr) && (sig == 'b') )  { arma_debug_warn_level(1,  "eig_gen(): 'balance' option ignored due to linking with crippled lapack"); }
+  if( auxlib::crippled_lapack(expr) && (sig == 'b') )  { arma_warn(1,  "eig_gen(): 'balance' option ignored due to linking with crippled lapack"); }
   
   const bool status = (sig == 'b') ? auxlib::eig_gen_twosided_balance(eigvals, leigvecs, reigvecs, expr.get_ref()) : auxlib::eig_gen_twosided(eigvals, leigvecs, reigvecs, expr.get_ref());
   
@@ -159,7 +159,7 @@ eig_gen
      eigvals.soft_reset();
     leigvecs.soft_reset();
     reigvecs.soft_reset();
-    arma_debug_warn_level(3, "eig_gen(): decomposition failed");
+    arma_warn(3, "eig_gen(): decomposition failed");
     }
   
   return status;
