@@ -32,7 +32,7 @@ enable_if2
   >::result
 repmat(const T1& A, const uword r, const uword c)
   {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
 
   return Op<T1, op_repmat>(A, r, c);
   }
@@ -45,7 +45,7 @@ arma_inline
 const SpOp<T1, spop_repmat>
 repmat(const SpBase<typename T1::elem_type,T1>& A, const uword r, const uword c)
   {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
 
   return SpOp<T1, spop_repmat>(A.get_ref(), r, c);
   }
