@@ -26,7 +26,7 @@ inline
 void
 op_diagmat::apply(Mat<typename T1::elem_type>& out, const Op<T1, op_diagmat>& X)
   {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
   
   typedef typename T1::elem_type eT;
   
@@ -109,7 +109,7 @@ inline
 void
 op_diagmat::apply(Mat<typename T1::elem_type>& out, const Proxy<T1>& P)
   {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
   
   const uword n_rows = P.get_n_rows();
   const uword n_cols = P.get_n_cols();
@@ -158,7 +158,7 @@ inline
 void
 op_diagmat::apply(Mat<typename T1::elem_type>& out, const Op< Glue<T1,T2,glue_times>, op_diagmat>& X)
   {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
   
   op_diagmat::apply_times(out, X.m.A, X.m.B);
   }
@@ -170,7 +170,7 @@ inline
 void
 op_diagmat::apply_times(Mat<typename T1::elem_type>& actual_out, const T1& X, const T2& Y, const typename arma_not_cx<typename T1::elem_type>::result* junk)
   {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
   arma_ignore(junk);
   
   typedef typename T1::elem_type eT;
@@ -181,10 +181,10 @@ op_diagmat::apply_times(Mat<typename T1::elem_type>& actual_out, const T1& X, co
   const typename partial_unwrap<T1>::stored_type& A = UA.M;
   const typename partial_unwrap<T2>::stored_type& B = UB.M;
   
-  arma_debug_assert_trans_mul_size< partial_unwrap<T1>::do_trans, partial_unwrap<T2>::do_trans >(A.n_rows, A.n_cols, B.n_rows, B.n_cols, "matrix multiplication");
+  arma_conform_assert_trans_mul_size< partial_unwrap<T1>::do_trans, partial_unwrap<T2>::do_trans >(A.n_rows, A.n_cols, B.n_rows, B.n_cols, "matrix multiplication");
   
-  const bool use_alpha = partial_unwrap<T1>::do_times || partial_unwrap<T2>::do_times;
-  const eT       alpha = use_alpha ? (UA.get_val() * UB.get_val()) : eT(0);
+  constexpr bool use_alpha = partial_unwrap<T1>::do_times || partial_unwrap<T2>::do_times;
+  const     eT       alpha = use_alpha ? (UA.get_val() * UB.get_val()) : eT(0);
   
   const uword A_n_rows = A.n_rows;
   const uword A_n_cols = A.n_cols;
@@ -198,7 +198,7 @@ op_diagmat::apply_times(Mat<typename T1::elem_type>& actual_out, const T1& X, co
     {
     if((A_n_rows == 1) || (B_n_cols == 1))
       {
-      arma_extra_debug_print("trans_A = false; trans_B = false; vector result");
+      arma_debug_print("trans_A = false; trans_B = false; vector result");
       
       const Mat<eT> C     = A*B;
       const eT*     C_mem = C.memptr();
@@ -216,7 +216,7 @@ op_diagmat::apply_times(Mat<typename T1::elem_type>& actual_out, const T1& X, co
     {
     if((A_n_cols == 1) || (B_n_cols == 1))
       {
-      arma_extra_debug_print("trans_A = true; trans_B = false; vector result");
+      arma_debug_print("trans_A = true; trans_B = false; vector result");
       
       const Mat<eT> C     = trans(A)*B;
       const eT*     C_mem = C.memptr();
@@ -234,7 +234,7 @@ op_diagmat::apply_times(Mat<typename T1::elem_type>& actual_out, const T1& X, co
     {
     if((A_n_rows == 1) || (B_n_rows == 1))
       {
-      arma_extra_debug_print("trans_A = false; trans_B = true; vector result");
+      arma_debug_print("trans_A = false; trans_B = true; vector result");
       
       const Mat<eT> C     = A*trans(B);
       const eT*     C_mem = C.memptr();
@@ -252,7 +252,7 @@ op_diagmat::apply_times(Mat<typename T1::elem_type>& actual_out, const T1& X, co
     {
     if((A_n_cols == 1) || (B_n_rows == 1))
       {
-      arma_extra_debug_print("trans_A = true; trans_B = true; vector result");
+      arma_debug_print("trans_A = true; trans_B = true; vector result");
       
       const Mat<eT> C     = trans(A)*trans(B);
       const eT*     C_mem = C.memptr();
@@ -275,7 +275,7 @@ op_diagmat::apply_times(Mat<typename T1::elem_type>& actual_out, const T1& X, co
   
   if( (partial_unwrap<T1>::do_trans == false) && (partial_unwrap<T2>::do_trans == false) )
     {
-    arma_extra_debug_print("trans_A = false; trans_B = false; matrix result");
+    arma_debug_print("trans_A = false; trans_B = false; matrix result");
     
     out.zeros(A_n_rows, B_n_cols);
     
@@ -318,7 +318,7 @@ op_diagmat::apply_times(Mat<typename T1::elem_type>& actual_out, const T1& X, co
   else
   if( (partial_unwrap<T1>::do_trans == true ) && (partial_unwrap<T2>::do_trans == false) )
     {
-    arma_extra_debug_print("trans_A = true; trans_B = false; matrix result");
+    arma_debug_print("trans_A = true; trans_B = false; matrix result");
     
     out.zeros(A_n_cols, B_n_cols);
     
@@ -339,7 +339,7 @@ op_diagmat::apply_times(Mat<typename T1::elem_type>& actual_out, const T1& X, co
   else
   if( (partial_unwrap<T1>::do_trans == false) && (partial_unwrap<T2>::do_trans == true ) )
     {
-    arma_extra_debug_print("trans_A = false; trans_B = true; matrix result");
+    arma_debug_print("trans_A = false; trans_B = true; matrix result");
     
     out.zeros(A_n_rows, B_n_rows);
     
@@ -362,7 +362,7 @@ op_diagmat::apply_times(Mat<typename T1::elem_type>& actual_out, const T1& X, co
   else
   if( (partial_unwrap<T1>::do_trans == true ) && (partial_unwrap<T2>::do_trans == true ) )
     {
-    arma_extra_debug_print("trans_A = true; trans_B = true; matrix result");
+    arma_debug_print("trans_A = true; trans_B = true; matrix result");
     
     out.zeros(A_n_cols, B_n_rows);
     
@@ -395,7 +395,7 @@ inline
 void
 op_diagmat::apply_times(Mat<typename T1::elem_type>& actual_out, const T1& X, const T2& Y, const typename arma_cx_only<typename T1::elem_type>::result* junk)
   {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
   arma_ignore(junk);
   
   typedef typename T1::pod_type   T;
@@ -407,10 +407,10 @@ op_diagmat::apply_times(Mat<typename T1::elem_type>& actual_out, const T1& X, co
   const typename partial_unwrap<T1>::stored_type& A = UA.M;
   const typename partial_unwrap<T2>::stored_type& B = UB.M;
   
-  arma_debug_assert_trans_mul_size< partial_unwrap<T1>::do_trans, partial_unwrap<T2>::do_trans >(A.n_rows, A.n_cols, B.n_rows, B.n_cols, "matrix multiplication");
+  arma_conform_assert_trans_mul_size< partial_unwrap<T1>::do_trans, partial_unwrap<T2>::do_trans >(A.n_rows, A.n_cols, B.n_rows, B.n_cols, "matrix multiplication");
   
-  const bool use_alpha = partial_unwrap<T1>::do_times || partial_unwrap<T2>::do_times;
-  const eT       alpha = use_alpha ? (UA.get_val() * UB.get_val()) : eT(0);
+  constexpr bool use_alpha = partial_unwrap<T1>::do_times || partial_unwrap<T2>::do_times;
+  const     eT       alpha = use_alpha ? (UA.get_val() * UB.get_val()) : eT(0);
   
   const uword A_n_rows = A.n_rows;
   const uword A_n_cols = A.n_cols;
@@ -424,7 +424,7 @@ op_diagmat::apply_times(Mat<typename T1::elem_type>& actual_out, const T1& X, co
     {
     if((A_n_rows == 1) || (B_n_cols == 1))
       {
-      arma_extra_debug_print("trans_A = false; trans_B = false; vector result");
+      arma_debug_print("trans_A = false; trans_B = false; vector result");
       
       const Mat<eT> C     = A*B;
       const eT*     C_mem = C.memptr();
@@ -442,7 +442,7 @@ op_diagmat::apply_times(Mat<typename T1::elem_type>& actual_out, const T1& X, co
     {
     if((A_n_cols == 1) || (B_n_cols == 1))
       {
-      arma_extra_debug_print("trans_A = true; trans_B = false; vector result");
+      arma_debug_print("trans_A = true; trans_B = false; vector result");
       
       const Mat<eT> C     = trans(A)*B;
       const eT*     C_mem = C.memptr();
@@ -460,7 +460,7 @@ op_diagmat::apply_times(Mat<typename T1::elem_type>& actual_out, const T1& X, co
     {
     if((A_n_rows == 1) || (B_n_rows == 1))
       {
-      arma_extra_debug_print("trans_A = false; trans_B = true; vector result");
+      arma_debug_print("trans_A = false; trans_B = true; vector result");
       
       const Mat<eT> C     = A*trans(B);
       const eT*     C_mem = C.memptr();
@@ -478,7 +478,7 @@ op_diagmat::apply_times(Mat<typename T1::elem_type>& actual_out, const T1& X, co
     {
     if((A_n_cols == 1) || (B_n_rows == 1))
       {
-      arma_extra_debug_print("trans_A = true; trans_B = true; vector result");
+      arma_debug_print("trans_A = true; trans_B = true; vector result");
       
       const Mat<eT> C     = trans(A)*trans(B);
       const eT*     C_mem = C.memptr();
@@ -501,7 +501,7 @@ op_diagmat::apply_times(Mat<typename T1::elem_type>& actual_out, const T1& X, co
   
   if( (partial_unwrap<T1>::do_trans == false) && (partial_unwrap<T2>::do_trans == false) )
     {
-    arma_extra_debug_print("trans_A = false; trans_B = false; matrix result");
+    arma_debug_print("trans_A = false; trans_B = false; matrix result");
     
     out.zeros(A_n_rows, B_n_cols);
     
@@ -541,7 +541,7 @@ op_diagmat::apply_times(Mat<typename T1::elem_type>& actual_out, const T1& X, co
   else
   if( (partial_unwrap<T1>::do_trans == true) && (partial_unwrap<T2>::do_trans == false) )
     {
-    arma_extra_debug_print("trans_A = true; trans_B = false; matrix result");
+    arma_debug_print("trans_A = true; trans_B = false; matrix result");
     
     out.zeros(A_n_cols, B_n_cols);
     
@@ -584,7 +584,7 @@ op_diagmat::apply_times(Mat<typename T1::elem_type>& actual_out, const T1& X, co
   else
   if( (partial_unwrap<T1>::do_trans == false) && (partial_unwrap<T2>::do_trans == true) )
     {
-    arma_extra_debug_print("trans_A = false; trans_B = true; matrix result");
+    arma_debug_print("trans_A = false; trans_B = true; matrix result");
     
     out.zeros(A_n_rows, B_n_rows);
     
@@ -622,7 +622,7 @@ op_diagmat::apply_times(Mat<typename T1::elem_type>& actual_out, const T1& X, co
   else
   if( (partial_unwrap<T1>::do_trans == true) && (partial_unwrap<T2>::do_trans == true) )
     {
-    arma_extra_debug_print("trans_A = true; trans_B = true; matrix result");
+    arma_debug_print("trans_A = true; trans_B = true; matrix result");
     
     out.zeros(A_n_cols, B_n_rows);
     
@@ -676,7 +676,7 @@ inline
 void
 op_diagmat2::apply(Mat<typename T1::elem_type>& out, const Op<T1, op_diagmat2>& X)
   {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
   
   typedef typename T1::elem_type eT;
   
@@ -706,7 +706,7 @@ inline
 void
 op_diagmat2::apply(Mat<typename T1::elem_type>& out, const Proxy<T1>& P, const uword row_offset, const uword col_offset)
   {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
   
   const uword n_rows = P.get_n_rows();
   const uword n_cols = P.get_n_cols();
@@ -742,7 +742,7 @@ op_diagmat2::apply(Mat<typename T1::elem_type>& out, const Proxy<T1>& P, const u
     }
   else  // P represents a matrix 
     {
-    arma_debug_check_bounds
+    arma_conform_check_bounds
       (
       ((row_offset > 0) && (row_offset >= n_rows)) || ((col_offset > 0) && (col_offset >= n_cols)),
       "diagmat(): requested diagonal out of bounds"
